
##########################################################################################################################
################################## Analyse de la Variance (ANOVA) ########################################################
#
# Une variable quantitative mesure dans  K>2 groupes (K=2 groupes: test de Student)
# intrt particulier: les groupes sont des modalits d'une ou plusieurs variable(s) qualitative(s) (ou niveaux de facteurs)
# l'ANOVA permet de tester s'il y a un "effet" du (des) facteur(s) sur la moyenne (cart d'un groupe par rapport  la moyenne gnrale)
#
##########################################################################################################################
##########################################################################################################################


##########################################################################################################################
####################### ANOVA   un facteur (1 var quantitative + 1 variable qualitative) ################################
##########################################################################################################################


###### EXEMPLE 1: Comparaison de scores de rsistance  un pathogne recueillis pour #################
###### quatre lignes indpendantes de Medicago truncatula (lgumineuses modle) #####################

## Les donnes
resistance = read.table("resistance.txt",header=T); resistance
attach(resistance);names(resistance)	# on peut accder aux variables en tapant leur nom 
table(lignee)					# affiche les effectifs des diffrents groupes (niveaux du facteur)
tapply(score,lignee,mean)			# affiche les scores moyens par groupe
tapply(score,lignee,summary)			# un rsum des donnes par groupe

## Reprsentations graphiques des donnes
hist(score,breaks=15)					# affiche un histogramme des scores, tout groupes confondus
boxplot(score~lignee,col="green",ylab="score")	# affichage de la "bote  moustache" des scores ppour chaque ligne

## Tester la normalit la normalit dans chaque groupe
shapiro.test(score[lignee=="HM008"])
shapiro.test(score[lignee=="A17"] )
shapiro.test(score[lignee=="DZA45"])
shapiro.test(score[lignee=="HM013"])	# conclusion ?

## Tester l'homognit (homosdasticit) des variances des 4 groupes
bartlett.test(score~lignee)

## ANOVA  1 facteur ("lignee")
# H0: moyenne(A)= moyenne(B)= moyenne(C)
# H1: au moins une moyenne diffre des autres
# en pratique on estime var(intergroupe) et var(intragroupe); puis test de Fisher sur les variances (H0:var(intergroupe) = var(intragroupe))  

res = aov(score~lignee)		# calcul des composantes de la variance avec focntion aov()
summary(res)			# IMPORTANT: TABLEAU de L'ANOVA (test de Fisher pour valuer la significativit du facteur: conclusion?
model.tables(res)			# diffrence des moyennes de chaque groupe avec la moyenne gnrale

## Chercher les ingalits de moyennes suite  l'ANOVA
# tests de Student pour comparer les groupes 2  2
t.test(score[lignee=="DZA45"],score[lignee=="HM013"],var.equal=T)
t.test(score[lignee=="DZA45"],score[lignee=="HM008"],var.equal=T)
t.test(score[lignee=="DZA45"],score[lignee=="A17"],var.equal=T)
t.test(score[lignee=="A17"],score[lignee=="HM013"],var.equal=T)
t.test(score[lignee=="HM008"],score[lignee=="HM013"],var.equal=T)
t.test(score[lignee=="A17"],score[lignee=="HM008"],var.equal=T)

## ==> ATTENTION AUX FAUX POSITIFS A CAUSE DES COMPARAISONS MULTIPLES !!!
# test de Student multiple
pairwise.t.test(score,lignee,p.adjust.method="bonferroni")	# comparaisons multiples avec correction de la p-valeur

# autre test: Test de Duncan
library(laercio)
LDuncan(res,conf.level = 0.99)					# identification des groupes similaires

# conclusion?

## REMARQUE: si les chantillons ne suivent pas la normalit ###########################
# ANOVA non paramtrique: test de Kruskall-Wallis
kruskal.test(score~lignee)
# tests de Wilcoxon/Mann-Whitney de comparaison des groupes (non-parametrique) 
wilcox.test(score[lignee=="HM008"],score[lignee=="A17"])
wilcox.test(score[lignee=="HM008"],score[lignee=="DZA45"])
#......
# test de Wilcoxon/Mann-Whitney multiple 
pairwise.wilcox.test(score,lignee) 
pairwise.wilcox.test(jitter(score),lignee,p.adjust.method="bonferroni") # rajouter un bruit aux valeurs pour rsoudre le problme des rangs identiques dans le test


##########################################################################################################################
####################### ANOVA   2 facteurs (1 var quantitative explique par 2 variables qualitatives): #################
####################### 2 facteurs (ici avec 2 niveaux chacun) et analyse de l'interaction entre facteurs ################ 
##########################################################################################################################

###### EXEMPLE 2:  Impact du type d'organisme transform utilis ("Ecoli","Levure") ########################
###### et du mode d'alimentation du fermenteur ("continu"/"step") sur la production d'un antibiotique  #####

## Les donnes
antibio = read.table("antibio.txt",header=T);antibio
attach(antibio);names(antibio)

## Reprsentations graphiques des donnes
par(mfrow=c(2,2))
boxplot(production~organisme, col="green",names=c("Ecoli","Levure"))               # production en fonction de l'espce (Ecoli/Yesat)
boxplot(production~alimentation, col="green",names=c("continu","step"))            # production en fonction du fermenteur (continu/step)
boxplot(production~organisme+alimentation, col="green",names=c("Ecol/continu","Levure/continu","Ecol/step","Levure/step"))

## Test de Normalit sur chaque chantillon
shapiro.test(production[organisme=='Ecoli' & alimentation=='continu'])
shapiro.test(production[organisme=='Ecoli' & alimentation=='step'])
shapiro.test(production[organisme=='Yeast' & alimentation=='continu'])
shapiro.test(production[organisme=='Yeast' & alimentation=='step'])

## Test d'galit des variances
bartlett.test(production~organisme+alimentation)

## ANOVA  2 facteurs (avec ou sans interaction)
model1 = aov(production~organisme*alimentation)	# ANOVA (les deux facteurs ainsi que leur interaction sont inclus dans le modle)
summary(model1)
interaction.plot(organisme,alimentation,production)

model2 = aov(production~organisme+alimentation)	# ANOVA (les deux facteurs sont inclus dans le modle)
summary(model2)

anova(model1,model2)
# si pas de diffrences on garde le modle le plus simple,
# si diffrence (modle 1 significativement diffrent de modle 2) on garde le modle prsentant le plus de termes significatifs

# Comparaisons de moyennes des fermenteurs pour chaque espces
t.test(production[organisme=='Ecoli' & alimentation=='continu'],production[organisme=='Ecoli' & alimentation=='step'],var.equal=T)	# comparaison fermenteurs ("continu" et "step") pour Ecoli
t.test(production[organisme=='Yeast' & alimentation=='continu'],production[organisme=='Yeast' & alimentation=='step'],var.equal=T)	# comparaison fermenteurs ("continu" et "step") pour Yeast

# Comparaisons de moyennes des espces pour chaque fermenteur
t.test(production[organisme=='Ecoli' & alimentation=='continu'],production[organisme=='Yeast' & alimentation=='continu'],var.equal=T)	# comparaison fermenteurs ("continu" et "step") pour Ecoli
t.test(production[organisme=='Ecoli' & alimentation=='step'],production[organisme=='Yeast' & alimentation=='step'],var.equal=T)		# comparaison fermenteurs ("continu" et "step") pour Yeast

# ==> le type d'alimentation ne change rien  la production, mais Ecoli est plus performante que la levure en terme de production 
#############################################################################################################################################





###################################################################################################################################
################################## PROBLEMES SUPPLEMENTAIRES ######################################################################
###################################################################################################################################

######################################################################################################
####################### ANOVA   un facteur (1 variable qualitative) #################################
######################################################################################################

###### PROBLEME 1: Comparaison de la production journalire de lait pour 3 races de vaches laitires ##

## Les donnes
vache = read.table("vache.txt",header=T) ; vache
attach(vache);names(vache)
#############################################################################################################################################



###### PROBLEME 2: Effet du type d'engrais ("A"/"B") et de la temprature ("High","Medium") sur la croissance des plantes #
## Les donnes
croissance<-read.table("croissance.txt",header=T)
attach(croissance);names(croissance)































