


###################################################################################################################################
################################## PROBLEME CORRIGE ###############################################################################
###################################################################################################################################

######################################################################################################
####################### ANOVA   un facteur (1 variable qualitative) #################################
######################################################################################################

###### PROBLEME 1: Comparaison de la production journalire de lait pour 3 races de vaches laitires ##

## Les donnes
vache = read.table("vache.txt",header=T) ; vache
attach(vache);names(vache)
tapply(prod_lait,race,mean)

# reprsentation graphique
boxplot(prod_lait~race,col="red")

## Tests prmiminaires (prsupposs pour l'ANOVA)
# Test de normalit
shapiro.test(prod_lait[race=="Abondance"])
shapiro.test(prod_lait[race=="Bearnaise"])
shapiro.test(prod_lait[race=="Jersiaise"])

# Test d'homognit des variances entre groupes - homoscdasticit
bartlett.test(prod_lait~race)

## ANOVA (analyse des composantes de la variances pour tester des diffrences de moyenne)
# H0: (A)= (B)= (C)
# H1: au moins une moyenne diffre des autres
# en pratique on estime var(intergroupe) et var(intragroupe) ; puis test de Fisher sur les variances (H0:var(intergroupe) = var(intragroupe))  

res = aov(prod_lait ~ race)	### composantes de la variance
summary(res)		### tableau d'ANOVA (ou "anova(res)" ou "summary.aov(res)")
model.tables(res)		### tailles d'effet (les diffrences entre chaque groupe et la moyenne globale)

# Test de normalit sur les rsidus de l'ANOVA
shapiro.test(residuals(res))

# test de Student multiple
pairwise.t.test(prod_lait,race,p.adjust.method="bonferroni")	# comparaisons multiples avec correction de la p-valeur
pairwise.wilcox.test(prod_lait,race)					# si pas de normalit
# test de Duncan
library(laercio)
LDuncan(res,conf.level = 0.99)
#############################################################################################################################################



###### PROBLEME 2: Effet du type d'engrais ("A"/"B") et de la temprature ("High","Medium") sur la croissance des plantes #
## Les donnes
croissance<-read.table("croissance.txt",header=T)
attach(croissance);names(croissance)

## Reprsentations graphiques des donnes
par(mfrow=c(2,2))
boxplot(hauteur~engrais, main="engrais",ylab="hauteur (cm)")
boxplot(hauteur~temperature, main="temperature",ylab="hauteur (cm)")
boxplot(hauteur~temperature+engrais, main="engrais-temperature",ylab="hauteur (cm)",las=3)

## Test de Normalit sur chaque chantillon
shapiro.test(hauteur[engrais=="A" & temperature=="Medium"])
shapiro.test(hauteur[engrais=="A" & temperature=="High"])
shapiro.test(hauteur[engrais=="B" & temperature=="Medium"])
shapiro.test(hauteur[engrais=="B" & temperature=="High"])

# Test d'galit des variances
bartlett.test(hauteur~temperature*engrais)

## ANOVA  2 facteurs (avec ou sans interaction)
model1<-aov(hauteur~temperature*engrais)	# modle d'ANOVA o l'on teste l'effet de 2 facteurs ainsi que leur interaction)
summary(model1)
interaction.plot(temperature,engrais,hauteur, main="interaction plot")

model2<-aov(hauteur~temperature+engrais)	# modle d'ANOVA o l'on teste l'effet de 2 facteurs sans leur interaction)
summary(model2)

anova(model1,model2)				# comparaison des 2 modles avec une ANOVA sur les rsidus des 2 modles
# si pas de diffrences on garde le modle le plus simple,
# si diffrence (modle 2 significativement diffrent de modle 1) on garde le modle prsentant le plus de termes significatifs

# Comparaison de moyenne des plantes avec engrais diffrents
t.test(hauteur[engrais=="A" & temperature=="High"],hauteur[engrais=="B" & temperature=="High"],var.equal=T)     # comparaison A/B pour temprature "High"
t.test(hauteur[engrais=="A" & temperature=="Medium"],hauteur[engrais=="B" & temperature=="Medium"],var.equal=T) # comparaison A/B pour temprature "Medium"

# Comparaison de moyenne des plantes avec tempratures diffrents
t.test(hauteur[engrais=="A" & temperature=="Medium"],hauteur[engrais=="A" & temperature=="High"],var.equal=T)   # comparaison High/Medium pour l'engrais A
t.test(hauteur[engrais=="B" & temperature=="Medium"],hauteur[engrais=="B" & temperature=="High"],var.equal=T)   # comparaison High/Medium pour l'engrais B
# une temprature modre augmente significativement la croissance, SURTOUT en prsence de l'engrais A 

groupes=factor(c(rep("M/A",4),rep("M/B",4),rep("H/A",4),rep("H/B",4)))
pairwise.t.test(hauteur,groupes,p.adjust.method="bonferroni")# comparaisons multiples 2  2: attention ici certaines groupes ne sont pas comparables (M/A vs H/B, M/B vs H/A) !!







